==> coffee4clients-0.2.1.tgz: package/README.md <==
# Coffee4Clients

Coffee4Clients allows Express.js to render `.coffee` files when `?js` is appended to their urls.


## Example

- http://localhost:5000/asd.coffee
	
	``` coffeescript
	alert 'asd'
	```

- http://localhost:5000/asd.coffee?js

	``` javascript
	(function() {
	  alert("awesome");
	}).call(this);
	```


## Installing


1. [Install Node.js](https://github.com/balupton/node/wiki/Installing-Node.js)

2. Install it

		npm install coffee4clients


## Using

- With Node.js in JavaScript

	``` javascript
	// Include Coffee4Clients
	require('coffee-script');
	coffee4clients = require('coffee4clients');

	// Setup with your Express Server
	coffee4clients.setup({
		server: null, // your express server (required)
		publicPath: '...', // the full path to your server root (required)
		missingAction: false, // the action to forward to when a file is not found
		cache: false // whether the responses should be cached
	});
	```

- With Node.js in CoffeeScript
	
	``` coffeescript
	# Include Coffee4Clients
	coffee4clients = require 'coffee4clients'

	# Setup with your Express Server
	coffee4clients.setup {
		server: null # your express server (required)
		publicPath: '...' # the full path to your server root (required)
		missingAction: false # the action to forward to when a file is not found
		cache: false # whether the responses should be cached
	}


## History

- v0.2 June 29, 2011
	- Now supports multiple instances
	- Has unit tests
	- Requires `?js` to be appended to `.coffee` urls

- v0.1 May 18, 2011
	- Initial commit


## License

Licensed under the [MIT License](http://creativecommons.org/licenses/MIT/)
Copyright 2011 [Benjamin Arthur Lupton](http://balupton.com)

==> coffee4clients-0.2.2.tgz: package/README.md <==
# Coffee4Clients

Coffee4Clients allows Express.js to render `.coffee` files when `?js` is appended to their urls.


## Example

- http://localhost:5000/asd.coffee
	
	``` coffeescript
	alert 'asd'
	```

- http://localhost:5000/asd.coffee?js

	``` javascript
	(function() {
	  alert("awesome");
	}).call(this);
	```


## Installing


1. [Install Node.js](https://github.com/balupton/node/wiki/Installing-Node.js)

2. Install it

		npm install coffee4clients


## Using

- With Node.js in JavaScript

	``` javascript
	// Include Coffee4Clients
	require('coffee-script');
	coffee4clients = require('coffee4clients');

	// Setup with your Express Server
	coffee4clients.createInstance({
		server: null, // your express server (required)
		publicPath: '...', // the full path to your server root (required)
		missingAction: false, // the action to forward to when a file is not found
		cache: false // whether the responses should be cached
	});
	```

- With Node.js in CoffeeScript
	
	``` coffeescript
	# Include Coffee4Clients
	coffee4clients = require 'coffee4clients'

	# Setup with your Express Server
	coffee4clients.createInstance {
		server: null # your express server (required)
		publicPath: '...' # the full path to your server root (required)
		missingAction: false # the action to forward to when a file is not found
		cache: false # whether the responses should be cached
	}


## History

- v0.2 June 29, 2011
	- Now supports multiple instances
	- Has unit tests
	- Requires `?js` to be appended to `.coffee` urls

- v0.1 May 18, 2011
	- Initial commit


## License

Licensed under the [MIT License](http://creativecommons.org/licenses/MIT/)
Copyright 2011 [Benjamin Arthur Lupton](http://balupton.com)
